# MultiMin

## What's New

`MultiMin` is under active development. Here you will find a list of features introduced in each version of the package.

## Version History

- **Versions 0.9.x**:
  - Beta versions.
  - All features working.
  - Unifying option props in plotting routines.

- **Versions 0.6.x**:
  - Include univariate distributions.
  - You can ask the CMND objects to show and return a simplified version of the function.
  - CMND objects now have a method to show in a table its parameters.
  - LaTeX support, ie. the CMND class is able to produce LaTeX code tabulating parameters and function.
  - A full example showing how to apply the tools in the package to the distribution in orbital elements is developed.
  - Initial value of the fitting parameters can now be set.

- **Versions 0.5.x**:

  - Official release of `MultiMin`.
  - Major refactoring of the codebase.
  - Improved documentation.
  - Conservative naming conventions.

### Planned Features

Future versions will include:

- **Versions 0.6.x**:

  - Richer density plots

---

*This document will be updated with each new release.*
